// -*-Mode: C++;-*-
/*
 * $Id: Login.h,v 2.3 2000/02/27 13:36:47 ral Exp $;
 * Include file for login-window
 */
#ifndef CLogin_included
#define CLogin_included

#include "LoginData.h"

class CLogin : public LoginData
{
    Q_OBJECT

public:
    CLogin(QWidget* parent = NULL,const char* name = NULL);
    virtual ~CLogin();
    const char*get_host()const{return HostEdit->text();}
    const char*get_pass()const{return PassEdit->text();}
    const char*get_user()const{return UserEdit->text();}
    const char*get_port()const{return PortEdit->text();}

protected slots:
    void focus_user();
    void focus_port();
    void focus_password();
    void focus_ok();
    void keyPressEvent(QKeyEvent*e);
protected:

};
#endif // CLogin_included
